@@ -30,7 +30,7 @@ def render_text_markup(text):
         complete_text = text
 
     md = markdown.Markdown(
-        extensions=["footnotes", "wikilinks"],
+        extensions=["footnotes", "wikilinks", "def_list"],
         extension_configs={
             # commented because current (2.0.3) version of Python Markdown
             # has bug http://www.freewisdom.org/projects/python-markdown/Tickets/000068
