@@ -47,6 +47,8 @@ def write_js(fileobj, catalog, use_fuzzy=False):
                 msgstr = message.string.encode(catalog.charset)
                 
         if msgid != '' and msgstr != msgid:
+            # escape msgstr
+            msgstr = msgstr.replace("'", "\\'")
             jss.append("'%s': '%s'" % (msgid, msgstr))
             
         #print msgid, msgstr
@@ -214,4 +216,4 @@ class CompileCatalogJs(Command):
             finally:
                 outfile.close()
             
-        
\ No newline at end of file
+        
